==> ns_asphalt9-1.0.10.tar.gz: ns_asphalt9-1.0.10/ns_asphalt9/core/page_factory.py <==
import datetime
import os
import shutil

from . import consts, pages, globals
from .cache import cache
from .utils.log import logger


class PageFactory:
    last_page = None

    def create_page(self, text: str):
        last_page_name = self.last_page.name if self.last_page else None
        match_pages = []
        page_instances = cache.scan(type="page")
        for page_instance in page_instances:
            weight = page_instance.calc_weight(text)
            if weight > 0:
                if last_page_name == consts.racing:
                    weight += 1
                match_pages.append((page_instance, weight))

        match_pages.sort(key=lambda pages: pages[1], reverse=True)

        if last_page_name in [consts.loading_race, consts.racing] and not match_pages:
            match_pages.append((pages.Racing, 1))

        if (
            not match_pages
            and text
            or len(match_pages) >= 2
            and match_pages[0][1] == match_pages[1][1]
        ):
            logger.info(f"match_pages = {match_pages}")
            # self.capture()

        if match_pages:
            page = match_pages[0][0](text, self.last_page)
        else:
            page = pages.Empty(text, self.last_page)
        methods = [method for method in dir(page) if callable(getattr(page, method))]
        for method in methods:
            if method.startswith("parse"):
                func = getattr(page, method)
                func()
        self.last_page = page
        globals.output_queue.put({"当前页面": page.name})
        return page

    def capture(self):
        debug = os.environ.get("A9_DEBUG", 0)
        filename = (
            "".join([str(d) for d in datetime.datetime.now().timetuple()]) + ".jpg"
        )
        if not debug:
            shutil.copy("./output.jpg", f"./{filename}")
        return filename


factory = PageFactory()

==> ns_asphalt9-1.2.6.tar.gz: ns_asphalt9-1.2.6/ns_asphalt9/core/page_factory.py <==
import datetime
import os
import shutil

from . import consts, pages, globals
from .cache import cache
from .utils.log import logger


class PageFactory:
    last_page = None

    def create_page(self, text: str, next_page: str = None):
        last_page_name = self.last_page.name if self.last_page else None
        match_pages = []
        page_instances = cache.scan(type="page")
        for page_instance in page_instances:
            if next_page:
                if page_instance.name == next_page:
                    match_pages.append((page_instance, 10))
                    break
            else:
                weight = page_instance.calc_weight(text)
                if weight > 0:
                    if last_page_name == consts.racing:
                        weight += 1
                    match_pages.append((page_instance, weight))

        match_pages.sort(key=lambda pages: pages[1], reverse=True)

        if last_page_name in [consts.loading_race, consts.racing] and not match_pages:
            match_pages.append((pages.Racing, 1))

        if (
            not match_pages
            and text
            or len(match_pages) >= 2
            and match_pages[0][1] == match_pages[1][1]
        ):
            logger.info(f"match_pages = {match_pages}")
            # self.capture()

        if match_pages:
            page = match_pages[0][0](text, self.last_page)
        else:
            page = pages.Empty(text, self.last_page)
        methods = [method for method in dir(page) if callable(getattr(page, method))]
        for method in methods:
            if method.startswith("parse"):
                func = getattr(page, method)
                func()
        self.last_page = page
        globals.output_queue.put({"当前页面": page.name})
        return page

    def capture(self):
        debug = os.environ.get("A9_DEBUG", 0)
        filename = (
            "".join([str(d) for d in datetime.datetime.now().timetuple()]) + ".jpg"
        )
        if not debug:
            shutil.copy("./output.jpg", f"./{filename}")
        return filename


factory = PageFactory()
